==> SPOT_0.1.1375.tar.gz: SPOT/R/spotFuncStartRastrigin.R <==
###################################################################################################
#' noisy Rastrigin function
#'
#' Example for SPOT optimizing the 6-hump camel back function, see 
#'   http://www.it.lut.fi/ip/evo/functions/node26.html
#'
#'
#' @param x	two dimensional vector that will be evauluated by the branin function
#'
#' @return number \code{y} \cr
#' - \code{y} is the function value of the corresponding \code{x} vector. Min function value: -1.031628453
#'
#' @references  \code{\link{SPOT}} \code{\link{spot}} \code{\link{demo}} \code{\link{spotFuncStartBranin}}
#' \code{\link{spotFuncStartBranin}} \code{\link{spotFuncStartRastrigin}}
###################################################################################################
spotRastriginFunction <- function (x) {  
  y<-sum(((x^2) - (cos(x*pi*2)*10))) + 10*length(x)
  return(y)
}

###################################################################################################
#' Rastrigin function call for SPOT
#'
#' SPOT uses this function for some demos to call the \code{\link{spotRastriginFunction}} function 
#' 
#' @param spotConfig Contains the list of spot configurations, results of the algorithm can be passed to this list instead of the .res file.
#'		  spotConfig defaults to "NA", and will only be passed to the Algorithm if spotConfig$spot.fileMode=FALSE. See also: \code{\link{spotGetOptions}}
#'			Items used are: \cr \cr
#'			alg.currentDesign: data frame holding the design points that will be evaluated \cr
#'			io.apdFileName: name of the apd file \cr
#'			io.desFileName: name of the des file \cr
#'			io.resFileName: name of the res file, for logging results (if spotConfig$spot.fileMode==TRUE)\cr
#'			spot.fileMode: boolean, if selected with true the results will also be written to the res file, otherwise it will only be saved in the spotConfig returned by this function\cr
#' @return this function returns the \code{spotConfig} list with the results in spotConfig$alg.currentResult
##' @references  \code{\link{SPOT}} \code{\link{spot}} \code{\link{demo}} \code{\link{spotFuncStartBranin}}
#' \code{\link{spotFuncStartBranin}} \code{\link{spotRastriginFunction}}
###################################################################################################
spotFuncStartRastrigin <- function(spotConfig){
	pdFile=spotConfig$io.apdFileName;
	resFileName=spotConfig$io.resFileName;	
	desFileName=spotConfig$io.desFileName;	
	
	if (spotConfig$spot.fileMode){ ##Check if spotConfig was passed to the algorithm, if yes the spot.fileMode is chosen with False wich means results have to be passed to spotConfig and not to res file.
		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr());
		## read doe/dace etc settings:
		des <- read.table(desFileName, sep=" ", header = TRUE);	
	}else{
		des <- spotConfig$alg.currentDesign; ##The if/else should not be necessary anymore, since des will always be written into the spotConfig
	}
	spotPrint(spotConfig$io.verbosity,1,summary(des));
	spotWriteLines(spotConfig$io.verbosity,1,"spotFuncStartRastrigin...", con=stderr());
	spotPrint(spotConfig$io.verbosity,1,pdFile)
	#default Values that can be changed with apd file
	noise<-spotConfig$spot.noise
	noise.type <- spotConfig$spot.noise.type
	spot.noise.minimum.at.value <- spotConfig$spot.noise.minimum.at.value
	f<-"Rastrigin"
	## read problem design file
	if(file.exists(pdFile)){
		source(pdFile,local=TRUE)
	}
	##  VARX1 VARX2 REPEATS SEED
	config<-nrow(des);
	spotPrint(spotConfig$io.verbosity,1,config);
	attach(des)	
	for (k in 1:config){
		for (i in 1:des$REPEATS[k]){
			dimcounter <- 1
			x <- NULL			
			while (exists(paste("VARX", dimcounter, sep=""))){
				name <- paste("VARX", dimcounter, sep="")
				varHelper  <- des[name]
				x <- cbind(x,varHelper[k,1])
				dimcounter <- dimcounter+1
			}
			
			x <- t(x)
			n <- dimcounter - 1
			conf <- k
			if (exists("CONFIG")){
				conf <- des$CONFIG[k]
			}
			if (exists("STEP")){
				step <- des$STEP[k]
			}
			seed <- des$SEED[k]+i-1			
			spotPrint(spotConfig$io.verbosity,1,c("Config:",k ," Repeat:",i))
			y <- spotRastriginFunction(x)
			## add noise
			y <- y + spotCalcNoise(y, noise=noise, noise.type=noise.type, spot.noise.minimum.at.value=spot.noise.minimum.at.value);
			spotPrint(spotConfig$io.verbosity,1,y)
			res <- NULL
			res <- list(Y=y,					
					#VARX1=x1,
					#VARX2=x2,
					Function=f,					
					DIM=n,
					STEP=step,
					SEED=seed,
					CONFIG=conf
			)
			
			for (counter in 1:(dimcounter-1)){
				res[paste("VARX", counter, sep="")] <- x[counter]
			}
			
			res <-data.frame(res)
			if (spotConfig$spot.fileMode){ ##Log the result in the .res file, only if user didnt set fileMode==FALSE
				colNames = TRUE
				if (file.exists(resFileName)){
					colNames = FALSE
				}				
				## quote = false is required for JAVA
				write.table(res
						, file = resFileName
						, row.names = FALSE
						, col.names = colNames
						, sep = " "              
						, append = !colNames
						, quote = FALSE
				);		
			}
			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res);							
		}			
	}	
	detach(des)
	return(spotConfig)
}
#
#	
#	
#	
#	
#	config<-nrow(des);
#	print(config);
#	if (is.null(des$CONFIG))
#	   stop("Design file is missing the required column CONFIG!")	   
#	for (k in 1:config){	 
#		for (i in 1:des$REPEATS[k]){
#			x1=des$x1[k]
#			x2=des$x2[k]			
#  		conf <- des$CONFIG[k]
#			seed <- des$SEED[k]+i			
#			cat(sprintf("Config: %5d,   Repeat: %5d\n",conf,i))		
#			browser()
#			y <- spotRastriginFunction(x1,x2,noise)
#			print(y)
#			res <- NULL
#			res <- list(Y=y
#					     ,x1=x1
#					     ,x2=x2
#					     ,SEED=seed
#					     ,CONFIG=conf                  
#					     ,REP=i
#			)
#			res <-data.frame(res)
#			colNames = TRUE
#			if (file.exists(resFileName)){
#				colNames = FALSE
#			}		
#			
#			write.table(res
#					, file = resFileName
#					, row.names = FALSE
#					, col.names = colNames
#					, sep = " "              
#					, append = !colNames               
#					, quote = FALSE
#			);			
#		}	# for (i)	 
#	}	# for (k)	
#}
#
#

==> SPOT_1.0.2661.tar.gz: SPOT/R/spotFuncStartRastrigin.R <==
###################################################################################################
#' Rastrigin function call interface for SPOT, deprecated
#'
#' SPOT uses this function for some demos to call the \code{\link{spotRastriginFunction}} function 
#' 
#' @param spotConfig Contains the list of spot configurations, results of the algorithm can be passed to this list instead of the .res file.
#'		  spotConfig defaults to "NA", and will only be passed to the Algorithm if spotConfig$spot.fileMode=FALSE. See also: \code{\link{spotGetOptions}}
#'			Items used are: \cr \cr
#'			alg.currentDesign: data frame holding the design points that will be evaluated \cr
#'			io.apdFileName: name of the apd file \cr
#'			io.desFileName: name of the des file \cr
#'			io.resFileName: name of the res file, for logging results (if spotConfig$spot.fileMode==TRUE)\cr
#'			spot.fileMode: boolean, if selected with true the results will also be written to the res file, otherwise it will only be saved in the spotConfig returned by this function\cr
#' @return this function returns the \code{spotConfig} list with the results in spotConfig$alg.currentResult
#' @seealso  \code{\link{SPOT}} \code{\link{spot}} \code{\link{demo}} \code{\link{spotFuncStartBranin}}
#' \code{\link{spotFuncStartBranin}} \code{\link{spotRastriginFunction}}
#' @keywords internal
###################################################################################################
spotFuncStartRastrigin <- function(spotConfig){
	pdFile=spotConfig$io.apdFileName;
	resFileName=spotConfig$io.resFileName;	
	desFileName=spotConfig$io.desFileName;	
	if(is.null(spotConfig$spot.noise)){spotConfig$spot.noise=10.0}
	if(is.null(spotConfig$spot.noise.type)){spotConfig$spot.noise.type="weighted"}
	if(is.null(spotConfig$spot.noise.minimum.at.value)){spotConfig$spot.noise.minimum.at.value=0.0}
	## spot.noise.type in {"weighted", "constant"}
	## weighted: y = y + y * noiseValue / 100
	## constant: y = y + noiseValue
		
	if (spotConfig$spot.fileMode){ ##Check if spotConfig was passed to the algorithm, if yes the spot.fileMode is chosen with False wich means results have to be passed to spotConfig and not to res file.
		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr());
		## read doe/dace etc settings:
		des <- read.table(desFileName, sep=" ", header = TRUE);	
	}else{
		des <- spotConfig$alg.currentDesign; ##The if/else should not be necessary anymore, since des will always be written into the spotConfig
	}
	spotPrint(spotConfig$io.verbosity,1,summary(des));
	spotWriteLines(spotConfig$io.verbosity,1,"spotFuncStartRastrigin...", con=stderr());
	spotPrint(spotConfig$io.verbosity,1,pdFile)
	#default Values that can be changed with apd file
	noise<-spotConfig$spot.noise
	noise.type <- spotConfig$spot.noise.type
	spot.noise.minimum.at.value <- spotConfig$spot.noise.minimum.at.value
	f<-"Rastrigin"
	## read problem design file
	if(file.exists(pdFile)){
		source(pdFile,local=TRUE)
	}
	##  VARX1 VARX2 REPEATS SEED
	config<-nrow(des);
	spotPrint(spotConfig$io.verbosity,1,config);
	attach(des)	
	for (k in 1:config){
		for (i in 1:des$REPEATS[k]){
			dimcounter <- 1
			x <- NULL			
			while (exists(paste("VARX", dimcounter, sep=""))){
				name <- paste("VARX", dimcounter, sep="")
				varHelper  <- des[name]
				x <- cbind(x,varHelper[k,1])
				dimcounter <- dimcounter+1
			}
			
			x <- t(x)
			n <- dimcounter - 1
			conf <- k
			if (exists("CONFIG")){
				conf <- des$CONFIG[k]
			}
			if (exists("STEP")){
				step <- des$STEP[k]
			}
			seed <- des$SEED[k]+i-1			
			spotPrint(spotConfig$io.verbosity,1,c("Config:",k ," Repeat:",i))
			y <- spotRastriginFunction(x)
			## add noise
			y <- y + spotCalcNoise(y, noise=noise, noise.type=noise.type, spot.noise.minimum.at.value=spot.noise.minimum.at.value);
			spotPrint(spotConfig$io.verbosity,1,y)
			res <- NULL
			res <- list(Y=y,					
					#VARX1=x1,
					#VARX2=x2,
					Function=f,					
					DIM=n,
					STEP=step,
					SEED=seed,
					CONFIG=conf
			)
			
			for (counter in 1:(dimcounter-1)){
				res[paste("VARX", counter, sep="")] <- x[counter]
			}
			
			res <-data.frame(res)
			if (spotConfig$spot.fileMode){ ##Log the result in the .res file, only if user didnt set fileMode==FALSE
				colNames = TRUE
				if (file.exists(resFileName)){
					colNames = FALSE
				}				
				## quote = false is required for JAVA
				write.table(res
						, file = resFileName
						, row.names = FALSE
						, col.names = colNames
						, sep = " "              
						, append = !colNames
						, quote = FALSE
				);		
			}
			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res);							
		}			
	}	
	detach(des)
	return(spotConfig)
}
#
#	
#	
#	
#	
#	config<-nrow(des);
#	print(config);
#	if (is.null(des$CONFIG))
#	   stop("Design file is missing the required column CONFIG!")	   
#	for (k in 1:config){	 
#		for (i in 1:des$REPEATS[k]){
#			x1=des$x1[k]
#			x2=des$x2[k]			
#  		conf <- des$CONFIG[k]
#			seed <- des$SEED[k]+i			
#			cat(sprintf("Config: %5d,   Repeat: %5d\n",conf,i))		
#			browser()
#			y <- spotRastriginFunction(x1,x2,noise)
#			print(y)
#			res <- NULL
#			res <- list(Y=y
#					     ,x1=x1
#					     ,x2=x2
#					     ,SEED=seed
#					     ,CONFIG=conf                  
#					     ,REP=i
#			)
#			res <-data.frame(res)
#			colNames = TRUE
#			if (file.exists(resFileName)){
#				colNames = FALSE
#			}		
#			
#			write.table(res
#					, file = resFileName
#					, row.names = FALSE
#					, col.names = colNames
#					, sep = " "              
#					, append = !colNames               
#					, quote = FALSE
#			);			
#		}	# for (i)	 
#	}	# for (k)	
#}
#
#
